package com.compdfkit.conversion.flutter.kmpdfkit_demo

import android.util.Log
import androidx.lifecycle.lifecycleScope
import com.compdfkit.conversion.*
import com.compdfkit.conversion.flutter.kmpdfkit_demo.utils.ConvertUtils
import io.flutter.embedding.engine.FlutterEngine
import io.flutter.plugin.common.EventChannel
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.launch

/**
 *  ConvertFlutterPlugin.kt
 *
 *  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 *  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 *  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 *  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 *  This notice may not be removed from this file.
 **/
class ConvertFlutterPlugin(var activity: MainActivity, flutterPlugin: FlutterEngine) : EventChannel.StreamHandler {

    private val channelName = "com.compdfkit.conversion.flutter.convert"


    companion object {

        val PARAMS_CONVERT_TYPE = "convertType"
        val PARAMS_FILE_PATH = "filePath"
        val PARAMS_FILE_NAME = "fileName"
        val PARAMS_DATA_TAG = "dataTag"
        val PARAMS_CONTAIN_IMAGES = "containImages"
        val PARAMS_CONTAIN_ANNOTATIONS = "containAnnotations"
        val PARAMS_WORK_SHEET_OPTIONS = "workSheetOptions"
        val PARAMS_CONTENTOPTIONS = "contentOptions"
        val PARAMS_IMAGE_DPI = "imageDpi"
        val PARAMS_IMAGE_PAGE_OPTIONS = "imagePageOptions"
        val PARAMS_MERGE_CSV = "mergeCSV"
        val PARAMS_HTML_PAGE_OPTIONS = "htmlPageOptions"

        val CONVERTING = 1
        val CONVERT_SUCCESS = 2
        val CONVERT_FAIL = 3
    }


    private var channel: EventChannel

    init {
        channel = EventChannel(flutterPlugin.dartExecutor.binaryMessenger, channelName)
        channel.setStreamHandler(this)
    }


    override fun onListen(arguments: Any?, events: EventChannel.EventSink?) {
        Log.e("conversion", "arguments:${arguments}")
        activity.lifecycleScope.launch(Dispatchers.IO) {
            var convertInfoMap = arguments as Map<String, String>
            val convertUtils = ConvertUtils()
            val options = convertUtils.getConvertOptions(convertInfoMap[PARAMS_CONVERT_TYPE] ?: "", convertInfoMap)
            val dataTag = convertInfoMap[PARAMS_DATA_TAG]

            convertUtils.onConvert(context = activity,
                filePath = convertInfoMap[PARAMS_FILE_PATH] ?: "",
                convertType = convertInfoMap[PARAMS_CONVERT_TYPE] ?: "", pageArrays = null, params = options, onHandle = {

                }, onProgress = { current, total ->
                    val progress = ((current / total.toFloat()) * 1000).toInt() / 10
                    val resultData = mapOf(
                        "progress" to progress,
                        "dataTag" to dataTag,
                        "status" to CONVERTING
                    )
                    Log.e("conversion", "progress:${progress}, dataTag:${dataTag}")
                    activity.lifecycleScope.launch(Dispatchers.Main) {
                        events?.success(resultData)

                    }
                }, onPost = { code, outFilePath ->
                    Log.e("conversion", "onPost， code:${code.name}, outputPath:${outFilePath}")
                    when (code) {
                        ConvertError.ERR_SUCCESS -> {
                            val process = mapOf(
                                "progress" to 100,
                                "dataTag" to dataTag,
                                "status" to CONVERT_SUCCESS,
                                "outputPath" to outFilePath
                            )
                            activity.lifecycleScope.launch(Dispatchers.Main) {
                                events?.success(process)
                            }
                        }
                        else -> {
                            val process = mapOf("progress" to 100, "dataTag" to dataTag, "status" to CONVERT_FAIL, "msg" to code.name)
                            activity.lifecycleScope.launch(Dispatchers.Main) {
                                events?.success(process)
                            }
                        }
                    }
                })
        }

    }

    override fun onCancel(arguments: Any?) {

    }


}
