package com.compdfkit.conversion.flutter.kmpdfkit_demo.utils

import android.content.Context
import com.compdfkit.conversion.*
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertFlutterPlugin.Companion.PARAMS_CONTAIN_ANNOTATIONS
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertFlutterPlugin.Companion.PARAMS_CONTAIN_IMAGES
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertFlutterPlugin.Companion.PARAMS_CONTENTOPTIONS
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertFlutterPlugin.Companion.PARAMS_HTML_PAGE_OPTIONS
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertFlutterPlugin.Companion.PARAMS_IMAGE_DPI
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertFlutterPlugin.Companion.PARAMS_IMAGE_PAGE_OPTIONS
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertFlutterPlugin.Companion.PARAMS_MERGE_CSV
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertFlutterPlugin.Companion.PARAMS_WORK_SHEET_OPTIONS
import com.compdfkit.conversion.flutter.kmpdfkit_demo.ConvertType

/**
 *  ConvertUtils.kt
 *
 *  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
 *
 *  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
 *  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
 *  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
 *  This notice may not be removed from this file.
 **/
class ConvertUtils {


    var cPDFConvert: CPDFConverter? = null

    fun onConvert(
        context: Context,
        filePath: String,
        convertType: String,
        pageArrays: IntArray? = null,
        params: CPDFConvertOptions,
        onHandle: ((objptr: Long) -> Unit)? = null,
        onProgress: ((current: Int, total: Int) -> Unit)? = null,
        onPost: ((code: ConvertError, outFilePath: String?) -> Unit)? = null
    ): ConvertError {
        val outputDir = FileUtils.getOutputFilePath(context)

        val uri = FileUtils.onGetUriBySystem(context, filePath) ?: return ConvertError.ERR_FILE
        return when (ConvertType.valueOf(convertType.uppercase())) {
            ConvertType.PPT -> CPDFConverterPPT(context, uri, "")
                .run {
                    cPDFConvert = this
                    convert(outputDir, "", params, pageArrays, onHandle, onProgress, onPost)
                }
            ConvertType.WORD -> CPDFConverterWord(context, uri, "")
                .run {
                    cPDFConvert = this
                    convert(outputDir, "", params as CPDFConvertWordOptions, pageArrays, onHandle, onProgress, onPost)
                }
            ConvertType.EXCEL -> CPDFConverterExcel(context, uri, "")
                .run {
                    cPDFConvert = this
                    convert(outputDir, "", params as CPDFConvertExcelOptions, pageArrays, onHandle, onProgress, onPost)
                }
            ConvertType.TXT -> CPDFConverterTxt(context, uri, "")
                .run {
                    cPDFConvert = this
                    convert(outputDir, "", params as CPDFConvertTxtOptions, pageArrays, onHandle, onProgress, onPost)
                }
            ConvertType.IMAGE -> CPDFConverterImg(context, uri, "").run {
                cPDFConvert = this
                convert(outputDir, "", params, pageArrays, onHandle, onProgress, onPost)
            }
            ConvertType.CSV -> CPDFConverterCsv(context, uri, "").run {
                cPDFConvert = this
                convert(outputDir, "", params, pageArrays, onHandle, onProgress, onPost)
            }
            ConvertType.RTF -> CPDFConverterRtf(context, uri, "").run {
                cPDFConvert = this
                convert(outputDir, "", params, pageArrays, onHandle, onProgress, onPost)
            }
            ConvertType.HTML -> CPDFConverterHtml(context, uri, "").run {
                cPDFConvert = this
                convert(outputDir, "", params, pageArrays, onHandle, onProgress, onPost)
            }
            else -> ConvertError.ERR_UNKNOWN
        }
    }

    fun getConvertOptions(convertType: String, optionsMap: Map<String, String>): CPDFConvertOptions {
        val isContainImages = optionsMap[PARAMS_CONTAIN_IMAGES].toBoolean()
        val isContainAnnotation = optionsMap[PARAMS_CONTAIN_ANNOTATIONS].toBoolean()
        val workSheetOptions = WorkSheetOptions.valueOf(optionsMap[PARAMS_WORK_SHEET_OPTIONS] ?: "")
        val contentOptions = ContentOptions.valueOf(optionsMap[PARAMS_CONTENTOPTIONS] ?: "")
        val imageDpi = optionsMap[PARAMS_IMAGE_DPI]
        val imagePageOptions = ImgType.valueOf(optionsMap[PARAMS_IMAGE_PAGE_OPTIONS] ?: "PNG")
        val mergeCSV = optionsMap[PARAMS_MERGE_CSV]?.toBoolean() ?: false
        val htmlPageOptions = PageAndNavigationPaneOptions.valueOf(optionsMap[PARAMS_HTML_PAGE_OPTIONS] ?: "")
        return when (ConvertType.valueOf(convertType.uppercase())) {
            ConvertType.PPT -> CPDFConvertPPTOptions().also {
                it.isContainImages = isContainImages
                it.isContainAnnotations = isContainAnnotation
            }
            ConvertType.WORD -> CPDFConvertWordOptions().also {
                it.isContainImages = isContainImages
                it.isContainAnnotations = isContainAnnotation
            }
            ConvertType.EXCEL -> CPDFConvertExcelOptions().also {
                it.isContainImages = isContainImages
                it.isContainAnnotations = isContainAnnotation
                it.workSheetOptions = workSheetOptions
                it.contentOptions = contentOptions
            }

            ConvertType.TXT -> CPDFConvertTxtOptions()
            ConvertType.IMAGE -> CPDFConvertImgOptions().also {
                it.isContainAnnotations = isContainAnnotation
                it.imageDpi = imageDpi?.toInt() ?: 300
                it.imgType = imagePageOptions
            }
            ConvertType.CSV -> CPDFConvertCsvOptions().also {
                it.isMergeCsv = mergeCSV
            }
            ConvertType.RTF -> CPDFConvertRtfOptions().also {
                it.isContainImages = isContainImages
                it.isContainAnnotations = isContainAnnotation
            }
            ConvertType.HTML -> CPDFConvertHtmlOptions().also {
                it.isContainImages = isContainImages
                it.isContainAnnotations = isContainAnnotation
                it.pageAndNavigationPaneOptions = htmlPageOptions
            }
            else -> CPDFConvertOptions()
        }
    }


}