import 'package:ConversionFlutterDemo/models/convert_contain_options_bean.dart';
import 'package:ConversionFlutterDemo/models/convert_type.dart';
import 'package:ConversionFlutterDemo/widgets/options/convert_excel_options_widget.dart';
import 'package:flutter/material.dart';

///  convert_options_provider.dart
///
///  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
///
///  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
///  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
///  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
///  This notice may not be removed from this file.
///
///record convert format options
class ConvertOptionsProvider extends ChangeNotifier {
  ConvertType convertType = ConvertType.none;

  ConvertOptionsBean pptOptions =
      ConvertOptionsBean(containImages: true, containAnnotations: true);

  ConvertOptionsBean wordOptions =
      ConvertOptionsBean(containImages: true, containAnnotations: true);

  ConvertOptionsBean excelOptions = ConvertOptionsBean(
      containImages: true,
      containAnnotations: false,
      workSheetOptions: ExcelWorkSheetOptions.ForEachPage,
      contentOptions: ContentOptions.AllContent);

  ConvertOptionsBean imageOptions = ConvertOptionsBean(
      containImages: true,
      containAnnotations: true,
      imageDpi: 300,
      imagePageOptions: ImagePageOptions.PNG);

  ConvertOptionsBean csvOptions = ConvertOptionsBean(mergeCSV: false);

  ConvertOptionsBean rtfOptions =
      ConvertOptionsBean(containImages: true, containAnnotations: true);

  ConvertOptionsBean htmlOptions = ConvertOptionsBean(
      containImages: true,
      containAnnotations: false,
      htmlPageOptions: HtmlPageOptions.SinglePage);

  ConvertOptionsBean getOptions() {
    switch (convertType) {
      case ConvertType.ppt:
        return pptOptions;
      case ConvertType.word:
        return wordOptions;
      case ConvertType.excel:
        return excelOptions;
      case ConvertType.image:
        return imageOptions;
      case ConvertType.csv:
        return csvOptions;
      case ConvertType.rtf:
        return rtfOptions;
      case ConvertType.html:
        return htmlOptions;
      default:
        return ConvertOptionsBean();
    }
  }

  void changeConvertType(ConvertType convertType) {
    this.convertType = convertType;
    notifyListeners();
  }

  void changePPTOptions({bool? containImages, bool? containAnnotations}) {
    if (containImages != null) {
      pptOptions.containImages = containImages;
    }
    if (containAnnotations != null) {
      pptOptions.containAnnotations = containAnnotations;
    }
    notifyListeners();
  }

  void changeWordOptions({bool? containImages, bool? containAnnotations}) {
    if (containImages != null) {
      wordOptions.containImages = containImages;
    }
    if (containAnnotations != null) {
      wordOptions.containAnnotations = containAnnotations;
    }
    notifyListeners();
  }

  void changeExcelOptions(
      {bool? containImages,
      bool? containAnnotations,
      ExcelWorkSheetOptions? workSheetOptions,
      ContentOptions? contentOptions}) {
    if (containImages != null) {
      excelOptions.containImages = containImages;
    }
    if (containAnnotations != null) {
      excelOptions.containAnnotations = containAnnotations;
    }
    if (workSheetOptions != null) {
      excelOptions.workSheetOptions = workSheetOptions;
    }
    if (contentOptions != null) {
      excelOptions.contentOptions = contentOptions;
    }
    notifyListeners();
  }

  void changeImageOptions(
      {bool? containImages,
      bool? containAnnotations,
      int? imageDpi,
      ImagePageOptions? imagePageOptions}) {
    if (containImages != null) {
      imageOptions.containImages = containImages;
    }
    if (containAnnotations != null) {
      imageOptions.containAnnotations = containAnnotations;
    }
    if (imageDpi != null) {
      imageOptions.imageDpi = imageDpi;
    }
    if (imagePageOptions != null) {
      imageOptions.imagePageOptions = imagePageOptions;
    }
    notifyListeners();
  }

  void changeCSVOptions(bool mergeCSV) {
    csvOptions.mergeCSV = mergeCSV;
    notifyListeners();
  }

  void changeRTFOptions({bool? containImages, bool? containAnnotations}) {
    if (containImages != null) {
      rtfOptions.containImages = containImages;
    }
    if (containAnnotations != null) {
      rtfOptions.containAnnotations = containAnnotations;
    }
    notifyListeners();
  }

  void changeHtmlOptions({bool? containImages, bool? containAnnotations,
      HtmlPageOptions? htmlPageOptions}) {
    if (containImages != null) {
      htmlOptions.containImages = containImages;
    }
    if (containAnnotations != null) {
      htmlOptions.containAnnotations = containAnnotations;
    }
    if (htmlPageOptions != null) {
      htmlOptions.htmlPageOptions = htmlPageOptions;
    }
    notifyListeners();
  }
}
